@@ -30,10 +30,10 @@
 G_BEGIN_DECLS
 
 #define GTK_TYPE_MOZ_EMBED             (gtk_moz_embed_get_type())
-#define GTK_MOZ_EMBED(obj)             GTK_CHECK_CAST((obj), GTK_TYPE_MOZ_EMBED, GtkMozEmbed)
-#define GTK_MOZ_EMBED_CLASS(klass)     GTK_CHEK_CLASS_CAST((klass), GTK_TYPE_MOZ_EMBED, GtkMozEmbedClass)
-#define GTK_IS_MOZ_EMBED(obj)          GTK_CHECK_TYPE((obj), GTK_TYPE_MOZ_EMBED)
-#define GTK_IS_MOZ_EMBED_CLASS(klass)  GTK_CHECK_CLASS_TYPE((klass), GTK_TYPE_MOZ_EMBED)
+#define GTK_MOZ_EMBED(obj)             G_TYPE_CHECK_INSTANCE_CAST((obj), GTK_TYPE_MOZ_EMBED, GtkMozEmbed)
+#define GTK_MOZ_EMBED_CLASS(klass)     G_TYPE_CHEK_CLASS_CAST((klass), GTK_TYPE_MOZ_EMBED, GtkMozEmbedClass)
+#define GTK_IS_MOZ_EMBED(obj)          G_TYPE_CHECK_INSTANCE_TYPE((obj), GTK_TYPE_MOZ_EMBED)
+#define GTK_IS_MOZ_EMBED_CLASS(klass)  G_TYPE_CHECK_CLASS_TYPE((klass), GTK_TYPE_MOZ_EMBED)
 
 typedef struct _GtkMozEmbed      GtkMozEmbed;
 typedef struct _GtkMozEmbedClass GtkMozEmbedClass;
@@ -117,10 +117,10 @@ guint32      gtk_moz_embed_get_chrome_mask  (GtkMozEmbed *embed);
 #define GTK_TYPE_MOZ_EMBED_CHROME_FLAGS \
              (gtk_moz_embed_chrome_flags_get_type())
 
-GtkType      gtk_moz_embed_progress_flags_get_type (void) G_GNUC_CONST;
-GtkType      gtk_moz_embed_status_enums_get_type (void) G_GNUC_CONST;
-GtkType      gtk_moz_embed_reload_flags_get_type (void) G_GNUC_CONST;
-GtkType      gtk_moz_embed_chrome_flags_get_type (void) G_GNUC_CONST;
+GType      gtk_moz_embed_progress_flags_get_type (void) G_GNUC_CONST;
+GType      gtk_moz_embed_status_enums_get_type (void) G_GNUC_CONST;
+GType      gtk_moz_embed_reload_flags_get_type (void) G_GNUC_CONST;
+GType      gtk_moz_embed_chrome_flags_get_type (void) G_GNUC_CONST;
 
 /* These are straight out of nsIWebProgressListener.h */
 
