@@ -636,13 +636,6 @@ gtk_moz_embed_set_comp_path(const char *aPath)
   EmbedPrivate::SetCompPath(aPath);
 }
 
-void
-gtk_moz_embed_set_app_components(const nsModuleComponentInfo* aComps,
-                                 int aNumComponents)
-{
-  EmbedPrivate::SetAppComponents(aComps, aNumComponents);
-}
-
 void
 gtk_moz_embed_set_profile_path(const char *aDir, const char *aName)
 {
@@ -746,66 +739,6 @@ gtk_moz_embed_go_forward(GtkMozEmbed *embed)
     embedPrivate->mNavigation->GoForward();
 }
 
-void
-gtk_moz_embed_render_data(GtkMozEmbed *embed, const char *data,
-			  guint32 len, const char *base_uri,
-			  const char *mime_type)
-{
-  EmbedPrivate *embedPrivate;
-
-  g_return_if_fail (embed != NULL);
-  g_return_if_fail (GTK_IS_MOZ_EMBED(embed));
-
-  embedPrivate = (EmbedPrivate *)embed->data;
-
-  embedPrivate->OpenStream(base_uri, mime_type);
-  //embedPrivate->AppendToStream((const PRUint8*)data, len);
-  embedPrivate->AppendToStream(data, len);
-  embedPrivate->CloseStream();
-}
-
-void
-gtk_moz_embed_open_stream(GtkMozEmbed *embed, const char *base_uri,
-			  const char *mime_type)
-{
-  EmbedPrivate *embedPrivate;
-
-  g_return_if_fail (embed != NULL);
-  g_return_if_fail (GTK_IS_MOZ_EMBED(embed));
-  g_return_if_fail (GTK_WIDGET_REALIZED(GTK_WIDGET(embed)));
-
-  embedPrivate = (EmbedPrivate *)embed->data;
-
-  embedPrivate->OpenStream(base_uri, mime_type);
-}
-
-void gtk_moz_embed_append_data(GtkMozEmbed *embed, const char *data,
-			       guint32 len)
-{
-  EmbedPrivate *embedPrivate;
-
-  g_return_if_fail (embed != NULL);
-  g_return_if_fail (GTK_IS_MOZ_EMBED(embed));
-  g_return_if_fail (GTK_WIDGET_REALIZED(GTK_WIDGET(embed)));
-
-  embedPrivate = (EmbedPrivate *)embed->data;
-  //embedPrivate->AppendToStream((const PRUint8*)data, len);
-  embedPrivate->AppendToStream(data, len);
-}
-
-void
-gtk_moz_embed_close_stream(GtkMozEmbed *embed)
-{
-  EmbedPrivate *embedPrivate;
-
-  g_return_if_fail (embed != NULL);
-  g_return_if_fail (GTK_IS_MOZ_EMBED(embed));
-  g_return_if_fail (GTK_WIDGET_REALIZED(GTK_WIDGET(embed)));
-
-  embedPrivate = (EmbedPrivate *)embed->data;
-  embedPrivate->CloseStream();
-}
-
 char *
 gtk_moz_embed_get_link_message(GtkMozEmbed *embed)
 {
@@ -969,57 +902,6 @@ gtk_moz_embed_get_nsIWebBrowser  (GtkMozEmbed *embed, nsIWebBrowser **retval)
     embedPrivate->mWindow->GetWebBrowser(retval);
 }
 
-PRUnichar *
-gtk_moz_embed_get_title_unichar (GtkMozEmbed *embed)
-{
-  PRUnichar *retval = nsnull;
-  EmbedPrivate *embedPrivate;
-                   
-  g_return_val_if_fail ((embed != NULL), (PRUnichar *)NULL);
-  g_return_val_if_fail (GTK_IS_MOZ_EMBED(embed), (PRUnichar *)NULL);
-  
-  embedPrivate = (EmbedPrivate *)embed->data;
-                   
-  if (embedPrivate->mWindow)
-    retval = NS_StringCloneData(embedPrivate->mWindow->mTitle);
-                   
-  return retval;
-}
-
-PRUnichar *
-gtk_moz_embed_get_js_status_unichar (GtkMozEmbed *embed)
-{
-  PRUnichar *retval = nsnull;
-  EmbedPrivate *embedPrivate;
-                   
-  g_return_val_if_fail ((embed != NULL), (PRUnichar *)NULL);
-  g_return_val_if_fail (GTK_IS_MOZ_EMBED(embed), (PRUnichar *)NULL);
-  
-  embedPrivate = (EmbedPrivate *)embed->data;
-                   
-  if (embedPrivate->mWindow)
-    retval = NS_StringCloneData(embedPrivate->mWindow->mJSStatus);
-                   
-  return retval;
-}
-
-PRUnichar *
-gtk_moz_embed_get_link_message_unichar (GtkMozEmbed *embed)
-{
-  PRUnichar *retval = nsnull;
-  EmbedPrivate *embedPrivate;
-                   
-  g_return_val_if_fail ((embed != NULL), (PRUnichar *)NULL);
-  g_return_val_if_fail (GTK_IS_MOZ_EMBED(embed), (PRUnichar *)NULL);
-  
-  embedPrivate = (EmbedPrivate *)embed->data;
-                   
-  if (embedPrivate->mWindow)
-    retval = NS_StringCloneData(embedPrivate->mWindow->mLinkMessage);
-                   
-  return retval;
-}
-
 // class and instance initialization
 
 GType
