@@ -102,6 +102,12 @@
 #include <nsMemory.h>
 #include <nsServiceManagerUtils.h>
 
+/* GTK_CHECK_CAST is masked by GTK_DISABLE_DEPRECATED in gtk+-2.14 */
+#ifndef GTK_CHECK_CAST
+#undef GTK_MOZ_EMBED
+#define GTK_MOZ_EMBED(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), GTK_TYPE_MOZ_EMBED, GtkMozEmbed))
+#endif
+
 #define KZ_GECKO_EMBED_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_GECKO_EMBED, KzGeckoEmbedPrivate))
 
 enum {
