@@ -43,6 +43,7 @@
 #include "kazehakase.h"
 #include "kz-mozhistorysearch.h"
 #include "kz-mozselectionlistener.h"
+#include "kz-mozcookiepromptservice.h"
 #ifdef HAVE_NSIBADCERTLISTENER_H
 #  include "GtkNSSDialogs.h"
 #endif
@@ -64,6 +65,7 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkPromptService)
 #ifdef HAVE_NSIBADCERTLISTENER_H
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
 #endif
+NS_GENERIC_FACTORY_CONSTRUCTOR(KzMozCookiePromptService)
 
 static const nsModuleComponentInfo sAppComps[] = {
 	{
@@ -116,6 +118,12 @@ static const nsModuleComponentInfo sAppComps[] = {
     		"@mozilla.org/embedcomp/prompt-service;1",
     		GtkPromptServiceConstructor
 	},
+	{
+		KZ_COOKIEPROMPTSERVICE_CLASSNAME,
+		KZ_COOKIEPROMPTSERVICE_CID,
+		KZ_COOKIEPROMPTSERVICE_CONTRACTID,
+		KzMozCookiePromptServiceConstructor
+	},
 };
 static const int sNumAppComps = G_N_ELEMENTS(sAppComps);
 
