@@ -8,32 +8,29 @@
 G_BEGIN_DECLS
 
 #define KZ_TYPE_FEED_INFO		(kz_feed_info_get_type ())
-#define KZ_FEED_INFO(obj)		(GTK_CHECK_CAST ((obj), KZ_TYPE_FEED_INFO, KzFeedInfo))
-#define KZ_FEED_INFO_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), KZ_TYPE_FEED_INFO, KzFeedInfoClass))
-#define KZ_IS_FEED_INFO(obj)		(GTK_CHECK_TYPE ((obj), KZ_TYPE_FEED_INFO))
-#define KZ_IS_FEED_INFO_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), KZ_TYPE_FEED_INFO))
-#define KZ_FEED_INFO_GET_CLASS(obj)	(GTK_CHECK_GET_CLASS ((obj), KZ_TYPE_FEED_INFO, KzFeedInfoClass))
+#define KZ_FEED_INFO(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_FEED_INFO, KzFeedInfo))
+#define KZ_FEED_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_FEED_INFO, KzFeedInfoClass))
+#define KZ_IS_FEED_INFO(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_FEED_INFO))
+#define KZ_IS_FEED_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_FEED_INFO))
+#define KZ_FEED_INFO_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_FEED_INFO, KzFeedInfoClass))
 
 typedef struct _KzFeedInfo      KzFeedInfo;
 typedef struct _KzFeedInfoClass KzFeedInfoClass;
 
 struct _KzFeedInfo
 {
-	GtkStatusbar parent;
+	GtkImageMenuItem parent;
 
 	/* Kazehakase */
 	KzWindow *kz;
 
-	GtkWidget *event_box;
-	GtkWidget *label;
-	
 	/* feed list */
 	GSList *feed_list;
 };
 
 struct _KzFeedInfoClass
 {
-	GtkStatusbarClass parent_class;
+	GtkImageMenuItemClass parent_class;
 };
 
 GType      kz_feed_info_get_type          (void) G_GNUC_CONST;
