@@ -21,8 +21,7 @@
 #ifndef __KZ_GESTURE_H__
 #define __KZ_GESTURE_H__
 
-#include <glib-object.h>
-#include <egg-action.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -33,17 +32,16 @@ G_BEGIN_DECLS
 #define KZ_IS_GESTURE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_GESTURE))
 #define KZ_GESTURE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_GESTURE, KzGestureClass))
 
-typedef struct _KzGesture KzGesture;
-typedef struct _KzGestureClass KzGestureClass;
-typedef struct _KzGestureDefTable KzGestureDefTable;
-typedef struct _KzGestureItem KzGestureItem;
-typedef struct _KzGestureItems KzGestureItems;
+typedef struct _KzGesture	KzGesture;
+typedef struct _KzGestureClass	KzGestureClass;
+typedef struct _KzGestureItem	KzGestureItem;
+typedef struct _KzGestureItems	KzGestureItems;
 
-#define	KZ_GESTURE_MOTION_TERMINATOR '\0'
-#define	KZ_GESTURE_MOTION_UP         'U'
-#define	KZ_GESTURE_MOTION_DOWN       'D'
-#define	KZ_GESTURE_MOTION_LEFT       'L'
-#define	KZ_GESTURE_MOTION_RIGHT      'R'
+#define	KZ_GESTURE_MOTION_TERMINATOR	'\0'
+#define	KZ_GESTURE_MOTION_UP		'U'
+#define	KZ_GESTURE_MOTION_DOWN		'D'
+#define	KZ_GESTURE_MOTION_LEFT		'L'
+#define	KZ_GESTURE_MOTION_RIGHT		'R'
 
 typedef gchar KzGestureMotion;
 
@@ -69,6 +67,7 @@ struct _KzGestureClass
 
 	/* -- signals -- */
 	void (*start)        (KzGesture *gesture);
+	void (*cancel)       (KzGesture *gesture);
 	void (*stack_motion) (KzGesture *gesture,
 			      KzGestureMotion motion);
 	void (*perform)      (KzGesture *gesture);
@@ -76,7 +75,7 @@ struct _KzGestureClass
 
 struct _KzGestureItem
 {
-	EggAction       *action;
+	GtkAction       *action;
 	gint             mode;
 	KzGestureMotion *sequence;
 };
@@ -87,16 +86,16 @@ struct _KzGestureItems
 	gint ref_count;
 };
 
-GType        kz_gesture_get_type               (void);
+GType        kz_gesture_get_type               (void) G_GNUC_CONST;
 KzGesture   *kz_gesture_new                    (void);
 
 void         kz_gesture_set_items              (KzGesture *gesture,
 						KzGestureItems *items);
 
-gboolean     kz_gesture_start                  (KzGesture *gesture,
+void         kz_gesture_start                  (KzGesture *gesture,
 						gint mode,
 						gint x, gint y);
-gboolean     kz_gesture_perform                (KzGesture *gesture);
+void         kz_gesture_perform                (KzGesture *gesture);
 void         kz_gesture_cancel                 (KzGesture *gesture);
 gboolean     kz_gesture_is_started             (KzGesture *gesture);
 void         kz_gesture_update_position        (KzGesture *gesture,
@@ -121,11 +120,11 @@ KzGestureItems *kz_gesture_items_new           (void);
 KzGestureItems *kz_gesture_items_ref           (KzGestureItems *items);
 void            kz_gesture_items_unref         (KzGestureItems *items);
 void            kz_gesture_items_set_action    (KzGestureItems *items,
-						EggAction *action,
+						GtkAction *action,
 						gint mode,
 						const KzGestureMotion *sequence);
 void            kz_gesture_items_unset_action  (KzGestureItems *items,
-						EggAction *action);
+						GtkAction *action);
 
 G_END_DECLS
 
