@@ -9,11 +9,11 @@
 G_BEGIN_DECLS
 
 #define KZ_TYPE_NOTEBOOK		(kz_notebook_get_type ())
-#define KZ_NOTEBOOK(obj)		(GTK_CHECK_CAST ((obj), KZ_TYPE_NOTEBOOK, KzNotebook))
-#define KZ_NOTEBOOK_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), KZ_TYPE_NOTEBOOK, KzNotebookClass))
-#define KZ_IS_NOTEBOOK(obj)		(GTK_CHECK_TYPE ((obj), KZ_TYPE_NOTEBOOK))
-#define KZ_IS_NOTEBOOK_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), KZ_TYPE_NOTEBOOK))
-#define KZ_NOTEBOOK_GET_CLASS(obj)	(GTK_CHECK_GET_CLASS ((obj), KZ_TYPE_NOTEBOOK, KzNotebookClass))
+#define KZ_NOTEBOOK(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_NOTEBOOK, KzNotebook))
+#define KZ_NOTEBOOK_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_NOTEBOOK, KzNotebookClass))
+#define KZ_IS_NOTEBOOK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_NOTEBOOK))
+#define KZ_IS_NOTEBOOK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_NOTEBOOK))
+#define KZ_NOTEBOOK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_NOTEBOOK, KzNotebookClass))
 
 typedef struct _KzNotebook      KzNotebook;
 typedef struct _KzNotebookClass KzNotebookClass;
