@@ -24,7 +24,6 @@
 
 #include <glib/gi18n.h>
 #include "kazehakase.h"
-#include "gobject-utils.h"
 #include "kz-thumbnail.h"
 #include "egg-pixbuf-thumbnail.h"
 #include "kz-marshalers.h"
@@ -32,6 +31,8 @@
 typedef struct _KzThumbnailsViewPrivate	KzThumbnailsViewPrivate;
 struct _KzThumbnailsViewPrivate
 {
+	KzBookmark *folder;
+	GList *children;
 	KzThumbnailsViewMode mode;
 };
 
@@ -44,12 +45,9 @@ enum {
 
 #define KZ_THUMBNAIL_BOOKMARK_KEY "KzThumbnail::Bookmark"
 
-static void     kz_thumbnails_view_class_init (KzThumbnailsViewClass *klass);
-static void     kz_thumbnails_view_init       (KzThumbnailsView      *view);
-static void     kz_thumbnails_view_dispose    (GObject              *object);
-
-static void 	kz_thumbnails_view_size_allocate (GtkWidget        *widget,
-                                         	  GtkAllocation    *allocation);
+static void     dispose       (GObject          *object);
+static void 	size_allocate (GtkWidget        *widget,
+      			       GtkAllocation    *allocation);
 
 static void 	kz_thumbnails_view_redraw 	 (KzThumbnailsView *view);
 
@@ -71,13 +69,9 @@ static gboolean cb_thumbnail_enter_notify    (GtkWidget        *widget,
 static gboolean cb_thumbnail_leave_notify    (GtkWidget        *widget,
 					      GdkEventCrossing *event);
 
-static GtkLayoutClass *parent_class = NULL;
-
 static gint kz_thumbnails_view_signals[LAST_SIGNAL] = {0};
 
-KZ_OBJECT_GET_TYPE(kz_thumbnails_view, "KzThumbnailsView", KzThumbnailsView,
-		   kz_thumbnails_view_class_init, kz_thumbnails_view_init,
-		   GTK_TYPE_TABLE)
+G_DEFINE_TYPE(KzThumbnailsView, kz_thumbnails_view, GTK_TYPE_TABLE)
 
 static void
 kz_thumbnails_view_class_init (KzThumbnailsViewClass *klass)
@@ -85,14 +79,12 @@ kz_thumbnails_view_class_init (KzThumbnailsViewClass *klass)
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class  = (GObjectClass *) klass;
 	widget_class  = (GtkWidgetClass *) klass;
 
-	object_class->dispose  = kz_thumbnails_view_dispose;
+	object_class->dispose  = dispose;
 
-	widget_class->size_allocate       = kz_thumbnails_view_size_allocate;
+	widget_class->size_allocate = size_allocate;
 
 	klass->activate = NULL;
 
@@ -113,9 +105,11 @@ static void
 kz_thumbnails_view_init (KzThumbnailsView *view)
 {
 	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE (view);
-	view->folder = NULL;
-	
-	priv->mode = KZ_THUMBNAILS_VIEW_VERTICAL;
+
+	priv->folder   = NULL;
+	priv->children = NULL;
+	priv->mode     = KZ_THUMBNAILS_VIEW_VERTICAL;
+
 	gtk_table_set_homogeneous(GTK_TABLE(view), FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(view), 4);
 	gtk_table_set_row_spacings(GTK_TABLE(view), 4);
@@ -123,37 +117,38 @@ kz_thumbnails_view_init (KzThumbnailsView *view)
 
 
 static void
-kz_thumbnails_view_dispose (GObject *object)
+dispose (GObject *object)
 {
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(object);
 	KzThumbnailsView *view = KZ_THUMBNAILS_VIEW(object);
 
-	if (view->folder)
+	if (priv->folder)
 	{
-		disconnect_bookmark_signals(view, view->folder);
-		g_object_unref(view->folder);
-		view->folder = NULL;
+		disconnect_bookmark_signals(view, priv->folder);
+		g_object_unref(priv->folder);
+		priv->folder = NULL;
 	}
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS(kz_thumbnails_view_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_thumbnails_view_parent_class)->dispose(object);
 }
 
 
 static void 	
-kz_thumbnails_view_size_allocate (GtkWidget *widget,
-                                  GtkAllocation *allocation)
+size_allocate (GtkWidget *widget,
+               GtkAllocation *allocation)
 {
 	GtkAllocation old_allocation;
 	gint old_width;
 	KzThumbnailsView *view;
-	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE (widget);
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(widget);
 	
 	view = KZ_THUMBNAILS_VIEW(widget);
 
 	old_allocation = widget->allocation;
 	old_width = old_allocation.width;
 
-  	GTK_WIDGET_CLASS(parent_class)->size_allocate (widget, allocation);
+  	GTK_WIDGET_CLASS(kz_thumbnails_view_parent_class)->size_allocate(widget, allocation);
 
 	if (priv->mode == KZ_THUMBNAILS_VIEW_PLANE &&
 	    old_width != allocation->width)
@@ -225,10 +220,11 @@ kz_thumbnails_view_set_thumbnail_at_pos (KzThumbnailsView *view,
 static void 
 kz_thumbnails_view_redraw (KzThumbnailsView *view)
 {
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE (view);
 	GList *node;
 	gint i = 0;
 
-	for (node = view->children; node; node = g_list_next(node))
+	for (node = priv->children; node; node = g_list_next(node))
 	{
 		GtkWidget *thumb = node->data;
 
@@ -253,31 +249,34 @@ kz_thumbnails_view_set_folder (KzThumbnailsView *view,
 			       KzBookmark *folder)
 {
 	GList *children, *node;
+	KzThumbnailsViewPrivate *priv;
 	
 	g_return_if_fail(KZ_IS_THUMBNAILS_VIEW(view));
 	g_return_if_fail(!folder || kz_bookmark_is_folder(folder));
 
-	if (view->folder)
+	priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(view);
+
+	if (priv->folder)
 	{
-		disconnect_bookmark_signals(view, view->folder);
-		g_object_unref(view->folder);
-		view->folder = NULL;
+		disconnect_bookmark_signals(view, priv->folder);
+		g_object_unref(priv->folder);
+		priv->folder = NULL;
 
 		/* remove old widgets */
-		g_list_foreach(view->children,
+		g_list_foreach(priv->children,
 			       destroy_child_widget, NULL);
-		g_list_free(view->children);
+		g_list_free(priv->children);
 	}
 
 	if (!folder) return;
 
-	view->folder = g_object_ref(folder);
-	connect_bookmark_signals(view, view->folder);
+	priv->folder = g_object_ref(folder);
+	connect_bookmark_signals(view, priv->folder);
 
 	children = kz_bookmark_get_children(folder);
 	for (node = children; node; node = g_list_next(node))
 	{
-		insert_bookmark(view, view->folder,
+		insert_bookmark(view, priv->folder,
 				node->data, NULL);
 	}
 	g_list_free(children);
@@ -305,12 +304,13 @@ find_thumbnail_widget (KzThumbnailsView *view, KzBookmark *bookmark)
 	GtkWidget *widget;
 	GList *children;
 	gint index;
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE (view);
 	
-	children = kz_bookmark_get_children(view->folder);
+	children = kz_bookmark_get_children(priv->folder);
 	index = g_list_index(children, bookmark); 
 	g_list_free(children);
 
-	widget = g_list_nth_data(view->children, index);
+	widget = g_list_nth_data(priv->children, index);
 
 	return widget;
 }
@@ -328,11 +328,7 @@ thumbnail_set_bookmark_property (GtkWidget *thumbnail, KzBookmark *bookmark)
 	
 	desc = kz_bookmark_get_description(bookmark);
 	if (desc)
-	{
-		GtkTooltips *tooltip;
-		tooltip = gtk_tooltips_new();
-		gtk_tooltips_set_tip(tooltip, thumbnail, desc, NULL);
-	}
+		gtk_widget_set_tooltip_text(thumbnail, desc);
 }
 
 
@@ -375,6 +371,7 @@ insert_bookmark (KzThumbnailsView *view,
 {
 	GtkWidget *thumbnail;
 	gint pos = -1;
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(view);
 
 	thumbnail = kz_thumbnail_new();
 	thumbnail_set_bookmark_property(thumbnail, child);
@@ -402,7 +399,7 @@ insert_bookmark (KzThumbnailsView *view,
 	{
 		GList *node, *pos_node;
 		gint i = pos + 1;
-		pos_node = g_list_nth(view->children, pos);
+		pos_node = g_list_nth(priv->children, pos);
 
 		for (node = pos_node; node; node = g_list_next(node))
 		{
@@ -418,9 +415,9 @@ insert_bookmark (KzThumbnailsView *view,
 	}
 	else
 	{
-		pos = g_list_length(view->children);
+		pos = g_list_length(priv->children);
 	}
-	view->children = g_list_insert(view->children,
+	priv->children = g_list_insert(priv->children,
 				       thumbnail,
 				       pos);
 
@@ -448,6 +445,7 @@ cb_bookmark_remove_child (KzBookmark *bookmark,
 			  KzThumbnailsView *view)
 {
 	GtkWidget *thumbnail;
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(view);
 
 	g_signal_handlers_disconnect_by_func
 		(child,
@@ -458,7 +456,7 @@ cb_bookmark_remove_child (KzBookmark *bookmark,
 	if (thumbnail)
 	{
 		gtk_widget_destroy(thumbnail);
-		view->children = g_list_remove(view->children, thumbnail);
+		priv->children = g_list_remove(priv->children, thumbnail);
 	}
 }
 
@@ -498,13 +496,14 @@ cb_thumbnail_release (GtkWidget *thumbnail, GdkEventButton *event,
 	KzBookmark *bookmark;
 	GList *children;
 	gint index;
+	KzThumbnailsViewPrivate *priv = KZ_THUMBNAILS_VIEW_GET_PRIVATE(view);
 	
 	if (event->button == 3)
 		return TRUE;
 
 	bookmark = g_object_get_data(G_OBJECT(thumbnail),
 				     KZ_THUMBNAIL_BOOKMARK_KEY);
-	children = kz_bookmark_get_children(view->folder);
+	children = kz_bookmark_get_children(priv->folder);
 	index = g_list_index(children, bookmark);
 	g_list_free(children);
 
