@@ -124,7 +124,8 @@ set_search_engine (GtkComboBox *combo)
 		gchar *engine_id = node->data;
 		gtk_combo_box_append_text(combo, engine_id);
 		i++;
-		if (strcmp(engine_id, search_engine_name) == 0)
+		if (search_engine_name &&
+		    strcmp(engine_id, search_engine_name) == 0)
 			active = i;
 		g_free(engine_id);
 	}
@@ -132,6 +133,7 @@ set_search_engine (GtkComboBox *combo)
 
 	if (search_engine_name)
 		g_free(search_engine_name);
+
 	gtk_combo_box_set_active(combo, active);
 }
 
