@@ -68,19 +68,6 @@ gboolean gtkutil_confirm_file_replace           (GtkWindow *parent,
 	}								       \
 }
 
-#if (GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION < 5)
-typedef enum {
-        GDK_PIXBUF_ROTATE_NONE             =   0,
-        GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE =  90,
-        GDK_PIXBUF_ROTATE_UPSIDEDOWN       = 180,
-        GDK_PIXBUF_ROTATE_CLOCKWISE        = 270
-} GdkPixbufRotation;
-				
-/* this function is taken from GTK+-2.5.x */
-GdkPixbuf *gdk_pixbuf_rotate_simple (const GdkPixbuf *src,
-				     GdkPixbufRotation angle);
-#endif
-
 G_END_DECLS
 
 #endif /* __GTKUTILS_H__ */
